@@ -39,7 +39,7 @@ class TestAlarmProcessor(unittest.TestCase):
         msg_tuple = message_tuple(json_msg)
         return [partition, alarm_tuple(offset, msg_tuple)]
 
-    @mock.patch('MySQLdb.connect')
+    @mock.patch('pymysql.connect')
     @mock.patch('monasca_notification.processors.alarm_processor.log')
     def _run_alarm_processor(self, alarm, sql_response, mock_log, mock_mysql):
         """Runs a mocked alarm processor reading from queue while running, returns (queue_message, log_message)
@@ -55,8 +55,13 @@ class TestAlarmProcessor(unittest.TestCase):
             mock_mysql.cursor.return_value = mock_mysql
             mock_mysql.__iter__.return_value = sql_response
 
-        processor = alarm_processor.AlarmProcessor(600, 'mysql_host', 'mysql_user',
-                                                   'mysql_passwd', 'dbname')
+        mysql_config = {'mysql': {'ssl': None,
+                                  'host': 'mysql_host',
+                                  'user': 'mysql_user',
+                                  'db': 'dbname',
+                                  'passwd': 'mysql_passwd'}}
+
+        processor = alarm_processor.AlarmProcessor(600, mysql_config)
 
         return processor.to_notification(alarm)
 
